/*
   FNT - SQL-backend for MySQL - function for grant all privileges in db to user

   Copyright (C) 2009 Free Software Foundation, Inc.

   Written by:
   Slava Zanko <slavazanko@gmail.com>


   This file is part of the FIDO New Technology.

   FIDO New Technology is free software: you can redistribute it and/or 
   modify it under the terms of the GNU General Public License as published 
   by the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
#ifdef HAVE_CONFIG_H
#	include <config.h>
#endif

#include <mysql.h>
#include <stdlib.h>
#include <string.h>

#include "../include/global.h"

#include "../include/types.h"
#include "../include/error.h"
#include "../include/plugin.h"
#include "../include/sql.h"

#include "main.h"

/*** global variables **************************************************/

/*** file scope macro definitions **************************************/

/*** file scope type declarations **************************************/

/*** file scope variables **********************************************/

/*** file scope functions **********************************************/

/*** public functions **************************************************/

DLLEXPORT bool
grant_to_user_all_db (fnt_sql_connect_t * sql_connect, const char *user_name, const char *db_name)
{
    fnt_sql_query_t *sql_query;
    char *esc_d, *esc_u;
    char *sql_command;

    esc_d = fnt_sql_escape (sql_connect, db_name);
    esc_u = fnt_sql_escape (sql_connect, user_name);
    sql_command = g_strdup_printf ("GRANT ALL ON %s.* TO '%s'@'%%'", esc_d, esc_u);
    g_free(esc_d);
    g_free(esc_u);

    sql_query = fnt_sql_query (sql_connect, sql_command);
    g_free(sql_command);

    if (sql_query == NULL)
    {
	fnt_error_push (FNT_MODULE_sql, FNT_SQL_E_DRIVER,
			_("%s - fail to grant privileges"), "Mysql");
	return false;
    }
    return fnt_sql_queryClear (&sql_query);
    return true;
}
